.. _drawing:

*******
Drawing
*******

Matplotlib
==========
.. automodule:: networkx.drawing.nx_pylab

.. currentmodule:: networkx
.. autosummary::
   :toctree: generated/

   draw
   draw_networkx
   draw_networkx_nodes
   draw_networkx_edges
   draw_networkx_labels
   draw_networkx_edge_labels
   draw_circular
   draw_random
   draw_spectral
   draw_spring
   draw_shell
   draw_graphviz



Graphviz AGraph (dot)
=====================
.. automodule:: networkx.drawing.nx_agraph

.. currentmodule:: networkx
.. autosummary::
   :toctree: generated/

   from_agraph
   to_agraph
   write_dot
   read_dot
   graphviz_layout
   pygraphviz_layout


Graphviz with pydot
===================
.. automodule:: networkx.drawing.nx_pydot

.. currentmodule:: networkx
.. autosummary::
   :toctree: generated/

   from_pydot
   to_pydot
   write_dot
   read_dot
   graphviz_layout
   pydot_layout


Graph Layout
============
.. automodule:: networkx.drawing.layout

.. currentmodule:: networkx
.. autosummary::
   :toctree: generated/

   circular_layout
   random_layout
   shell_layout
   spring_layout
   spectral_layout

